ansi

package
v0.1.47 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2024 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package ansi reference https://github.com/sindresorhus/ansi-escapes

Index

Constants

This section is empty.

Variables

var CursorLeft = fmt.Sprintf("%sG", csi)

CursorLeft move cursor to the left side

var EraseDown = fmt.Sprintf("%sJ", csi)

EraseDown Erase the screen from the current line down to the bottom of the

var EraseUp = fmt.Sprintf("%s1J", csi)

EraseUp Erase the screen from the current line up to the top of the screen

Functions

func CursorPrevLine

func CursorPrevLine(count int) string

CursorPrevLine Move cursor up a specific amount of rows.

func CursorTo

func CursorTo(x, y int) string

CursorTo Set the absolute position of the cursor. `x` `y` is the top left of the screen.

func CursorUp

func CursorUp(count int) string

CursorUp Move cursor up a specific amount of rows.

Types

This section is empty.

Jump to