Documentation
¶
Overview ¶
Package ansi reference https://github.com/sindresorhus/ansi-escapes
Index ¶
Constants ¶
This section is empty.
Variables ¶
var CursorLeft = fmt.Sprintf("%sG", csi)
CursorLeft move cursor to the left side
var EraseDown = fmt.Sprintf("%sJ", csi)
EraseDown Erase the screen from the current line down to the bottom of the
var EraseUp = fmt.Sprintf("%s1J", csi)
EraseUp Erase the screen from the current line up to the top of the screen
Functions ¶
func CursorPrevLine ¶
CursorPrevLine Move cursor up a specific amount of rows.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.